@@ -1,4 +1,5 @@
 from datetime import datetime
+from decimal import Decimal
 
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
@@ -270,6 +271,9 @@ class EventRegistration(ExtensibleModel):
         RegistrationState, verbose_name=_("States"), related_name="registrations"
     )
 
+    def get_person(self):
+        return self.person
+
     def get_invoice(self):
         # FIXME Maybe do not hard-code this
         client, __ = Client.objects.get_or_create(name="Teckids e.V.")
@@ -310,9 +314,9 @@ class EventRegistration(ExtensibleModel):
         yield PurchasedItem(
             name=self.event.display_name,
             quantity=1,
-            price=self.event.cost,
+            price=Decimal(self.event.cost / 1.07),
             currency="EUR",
-            sku="",
+            sku="EVENT",
             tax_rate=7,
         )
 
@@ -321,9 +325,9 @@ class EventRegistration(ExtensibleModel):
             yield PurchasedItem(
                 name=_("Social Sponsoring / Extra Donation"),
                 quantity=1,
-                price=self.donation,
+                price=Decimal(self.donation),
                 currency="EUR",
-                sku="",
+                sku="DONAT",
                 tax_rate=0,
             )
 
@@ -332,17 +336,17 @@ class EventRegistration(ExtensibleModel):
             yield PurchasedItem(
                 name=_("Voucher / Granted discount"),
                 quantity=1,
-                price=-1 * self.voucher.discount * self.event.cost / 100,
+                price=Decimal(-1 * self.voucher.discount * (self.event.cost / 1.07) / 100),
                 currency="EUR",
-                sku="",
+                sku="DISCO",
                 tax_rate=7,
             )
 
     def _get_total_amount(self):
         total, tax = 0, 0
         for item in self.get_purchased_items():
-            total += item.price
-            tax += item.price / (item.tax_rate + 100) * item.tax_rate
+            tax += item.price * item.tax_rate / 100
+            total += item.price + tax
         return total, tax
 
     def __str__(self) -> str:
